@@ -10,7 +10,7 @@ import os
 from pathlib import Path
 
 
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 
 
 StrBytes = Union[str, bytes]
@@ -58,7 +58,7 @@ async def run(
     capture_output: bool = False,
     check: bool = False,
     text: Optional[bool] = None,
-) -> subprocess.CompletedProcess:
+) -> Union[subprocess.CompletedProcess[str], subprocess.CompletedProcess[bytes]]:
     """An async clone of `subprocess.run`.
 
     Suppose you have Python script that orchestrates shell commands,
